#
# spec file for package rkward
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Leap before 15.2 doesn't have a new enough QtWebEngine (5.12 is the minimum version)
%if 0%{?suse_version} > 1500 || 0%{?sle_version} >= 150200
# QtWebEngine is not available on ppc
%ifarch %{ix86} x86_64 %{arm} aarch64 mips mips64
%bcond_without qtwebengine
%else
%bcond_with qtwebengine
%endif
%else
%bcond_with qtwebengine
%endif
Name:           rkward
Version:        0.7.5
Release:        3.6
Summary:        Graphical frontend for R language
Summary(fr):    Interface graphique pour le langage R
License:        GPL-2.0-only
Group:          Productivity/Scientific/Math
URL:            https://rkward.kde.org/
Source0:        https://download.kde.org/stable/%{name}/%{version}/src/%{name}-%{version}.tar.gz
Patch0:         Fix_handling_carriage_returns.patch
Patch1:         Fix_Syntax_Pipe.patch
BuildRequires:  R-base-devel
BuildRequires:  cmake
BuildRequires:  extra-cmake-modules
BuildRequires:  gcc-fortran
BuildRequires:  gettext
BuildRequires:  karchive-devel
BuildRequires:  kconfig-devel
BuildRequires:  kcoreaddons-devel
BuildRequires:  kcrash-devel
BuildRequires:  kdoctools-devel
BuildRequires:  kf5-filesystem
BuildRequires:  ki18n-devel
BuildRequires:  knotifications-devel
BuildRequires:  kparts-devel
BuildRequires:  ktexteditor-devel
BuildRequires:  kwidgetsaddons-devel
BuildRequires:  kwindowsystem-devel
BuildRequires:  kxmlgui-devel
BuildRequires:  update-desktop-files
BuildRequires:  cmake(Qt5Core)
BuildRequires:  cmake(Qt5Network)
BuildRequires:  cmake(Qt5PrintSupport)
BuildRequires:  cmake(Qt5Script)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  cmake(Qt5Xml)
%if %{with qtwebengine}
BuildRequires:  cmake(Qt5WebEngineWidgets) >= 5.12.0
%else
BuildRequires:  kdewebkit-devel
BuildRequires:  cmake(Qt5WebKitWidgets)
%endif
Recommends:     kate-plugins
Suggests:       kbibtex
Suggests:       pandoc
# rkward needs the R-base version it was compiled with - boo#993268
%requires_eq    R-base

%description
RKWard aims to provide an easily extensible, easy to use IDE/GUI for the
R-project. RKWard tries to combine the power of the R-language with the
(relative) ease of use of commercial statistics tools. Long term plans
include integration with office suites

%description -l fr
RKWard fournis un environnement de développement graphique intégré
aisément extensible et simple d'utilisation. RKWard tente de
combiner la puissance du langage R et la (relative) simplicité d'utilisation
des outils statistiques commerciaux. L'objectif à long terme est de voir son
intégration dans les suites bureautiques.

%prep
%autosetup -p1

%build
%cmake_kf5 -d build
%make_jobs

%install
%make_install -C build

%suse_update_desktop_file -n org.kde.rkward

%find_lang %{name}

%files -f %{name}.lang
%doc README TODO AUTHORS
%doc %{_kf5_mandir}/man1/rkward.1.gz
%dir %{_kf5_sharedir}/doc/HTML/en/rkwardplugins
%doc %{_kf5_sharedir}/doc/HTML/en/rkwardplugins/index.cache.bz2
%doc %{_kf5_sharedir}/doc/HTML/en/rkwardplugins/index.docbook
%doc %{_kf5_sharedir}/doc/HTML/en/rkwardplugins/menu_hierarchy_example.png
%doc %{_kf5_sharedir}/doc/HTML/en/rkwardplugins/t_test_plugin_example.png
%license COPYING
%{_kf5_applicationsdir}/org.kde.rkward.desktop
%{_kf5_appstreamdir}/org.kde.rkward.appdata.xml
%{_kf5_sharedir}/icons/hicolor/16x16/apps/rkward.png
%{_kf5_sharedir}/icons/hicolor/22x22/apps/rkward.png
%{_kf5_sharedir}/icons/hicolor/32x32/apps/rkward.png
%{_kf5_sharedir}/icons/hicolor/48x48/apps/rkward.png
%{_kf5_sharedir}/icons/hicolor/64x64/apps/rkward.png
%{_kf5_sharedir}/icons/hicolor/128x128/apps/rkward.png
%{_kf5_sharedir}/icons/hicolor/scalable/apps/rkward.svgz
%{_kf5_sharedir}/ktexteditor_snippets/
%{_kf5_bindir}/rkward*
%if %{pkg_vcmp kf5-filesystem >= 20220307}
%{_libexecdir}/rkward.rbackend
%else
%{_kf5_libdir}/libexec/
%endif
%{_kf5_sharedir}/rkward/
%{_kf5_servicesdir}/rkward.protocol
%if 0%{?suse_version} > 1320 || (0%{?suse_version} == 1315 && 0%{?sle_version} >= 120300)
# we have the syntax-highlighting framework since Leap 42.3
%dir %{_kf5_sharedir}/org.kde.syntax-highlighting
%dir %{_kf5_sharedir}/org.kde.syntax-highlighting/syntax
%{_kf5_sharedir}/org.kde.syntax-highlighting/syntax/rkward.xml
%else
%dir %{_kf5_sharedir}/katepart5
%dir %{_kf5_sharedir}/katepart5/syntax
%{_kf5_sharedir}/katepart5/syntax/rkward.xml
%endif
%{_kf5_sharedir}/mime/packages/vnd.kde.rkward-output.xml
%{_kf5_sharedir}/mime/packages/vnd.kde.rmarkdown.xml
%{_kf5_sharedir}/mime/packages/vnd.rkward.r.xml

# language files

%dir %{_kf5_sharedir}/rkward/po/
%lang(ca) %{_kf5_sharedir}/rkward/po/ca/
%lang(es) %{_kf5_sharedir}/rkward/po/es/
%lang(gl) %{_kf5_sharedir}/rkward/po/gl/
%lang(nl) %{_kf5_sharedir}/rkward/po/nl/
%lang(pl) %{_kf5_sharedir}/rkward/po/pl/
%lang(pt) %{_kf5_sharedir}/rkward/po/pt/
%lang(pt_BR) %{_kf5_sharedir}/rkward/po/pt_BR/
%lang(sv) %{_kf5_sharedir}/rkward/po/sv/
%lang(uk) %{_kf5_sharedir}/rkward/po/uk/

%doc %lang(en) %{_kf5_sharedir}/doc/HTML/en/rkward/
%doc %lang(it) %{_kf5_sharedir}/doc/HTML/it/rkward/
%doc %lang(nl) %{_kf5_sharedir}/doc/HTML/nl/rkward/
%doc %lang(sv) %{_kf5_sharedir}/doc/HTML/sv/rkward/
%doc %lang(uk) %{_kf5_sharedir}/doc/HTML/uk/rkward/

%doc %lang(nl) %{_kf5_sharedir}/doc/HTML/nl/rkwardplugins/
%doc %lang(sv) %{_kf5_sharedir}/doc/HTML/sv/rkwardplugins/
%doc %lang(uk) %{_kf5_sharedir}/doc/HTML/uk/rkwardplugins/

%doc %lang(ca) %{_kf5_mandir}/ca/man1/rkward.1.gz
%doc %lang(de) %{_kf5_mandir}/de/man1/rkward.1.gz
%doc %lang(it) %{_kf5_mandir}/it/man1/rkward.1.gz
%doc %lang(nl) %{_kf5_mandir}/nl/man1/rkward.1.gz
%doc %lang(sv) %{_kf5_mandir}/sv/man1/rkward.1.gz
%doc %lang(uk) %{_kf5_mandir}/uk/man1/rkward.1.gz

%changelog
* Fri Feb 23 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
* Fri Jan  5 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Add extra-cmake-module BuildRequires: This used to be dragged in
  by other deps before, but cmake explicitly checks for it here.
* Wed Dec 28 2022 Pierre Bonamy <flyos@mailoo.org>
- Add Fix_Syntax_Pipe.patch: Backport fix to properly highlight
  the native pipe "|>" as an operator in the R console.
* Tue Dec 27 2022 Pierre Bonamy <flyos@mailoo.org>
- Backport fix to display progress bars from 'cli' package in
  RKWard R console. See "Fix_handling_carriage_returns.patch".
* Tue Nov  8 2022 Pierre Bonamy <flyos@mailoo.org>
- Update to upstream release 0.7.5
- New features and improvements
  * Added: Partial completions (Tab-key) consider completion candidates from all visible completion groups
  * Added: R's dynamic completions (importantly for ":::", "?", and "@") are merged into the already provided completions
  * Added: Add option to offer code completion/hinting in all file types not just R scripts (e.g. in .Rmd files)
  * Changed default behavior (new installations, only): Up/down without alt navigate completion items if visible in console/editor
  * Added: Provide tooltips on symbols in scripts and R console
  * Added: Many new basic and advanced R, R Markdown and LaTeX snippets, including complete R Markdown templates
  * Added: Allow to select search provider, when searching for a term online
  * Added: Allow to restart R backend (e.g. for testing that scripts or packages will work in a fresh session)
  * Changed: Actions to restart the R backend, interrupt all commands and configure the R backend arranged in a hmburger menu
  * Added: Crosstabs N to N: Simplify labels, add option to control table layout
  * Added: Change mechanism for detection of object changes
- Bug fixes
  * Fixed: Backend failed to start when installed in a path with spaces on Windows volumes without 8.3 support
  * Fixed: Trying to restart backend could cause a hang, on Windows
  * Fixed: In corner cases, cancelling commands could lead to a lockup
  * Fixed: IRT Cronbach's Alpha did not work for subsets, if the data.frame name contains dots
  * Fixed: Action to remove several rows in data editor, simultaneously, always remained disabled
  * Fixed: Workspace browser would not always show change, immediately, when object type changes
  * Fixed: Crash when using the "Git blame" kate plugin
  * Fixed: Problem installing R support package in some configurations
  * Fixed: Menubar would disapper after opening script editor, in some configurations
  * Fixed: Very long error messages during R markdown preview could cause the preview window to become too wide
  * Fixed: Expresssions spanning several lines would not be shown, correctly, in "R Console"-mode script preview
  * Fixed: Fix focus problems, and better efficiency for data previews (as used in data import dialogs)
  * Fixed: Excel import plugin failed to accept file name
  * Fixed: Fix zooming help/output pages with Ctrl+scroll wheel, when compiled with QWebEngine
  * Fixed: Fix problem handling rkward:// links from dialogs on some sytems
  * Fixed: Fix object name completion for (irregular) names starting with numbers or underscores
* Thu Jun  2 2022 Wolfgang Bauer <wbauer@tmo.at>
- Update to upstream release 0.7.4
- New features and improvements
  * Support "step into" and "finish current" modes in the R debugger window
  * When directly upgrading from very old versions (pre 0.6.3, currently), discard existing config settings
  * Plugin maps with the same id are grouped together, and the most recent version is used, automatically
  * Added functionality to install add-on packages directly from git (formerly available as external plugin rk.gitInstall)
  * Add option to show ANOVA table for linear regression
  * Add default preview() function is available to plugins, reducing the code needed to add preview functionality
  * Add preview functionality to most existing plugins that did not have it, yet
  * Better placement of messages in non-plot preview windows
  * Package installation uses inline widget to provide progress feedback, instead of separate dialogs
  * Package installation no longer uses an external process, unless required for root permissions
  * (Re-)added improved "Import Assistant" to help getting started with importing data
  * "Paste special" can now also paste data.frames with labels, and is available in the Workspace Browser context menu
  * Add "rio"-based generic import plugin
  * Allow separate analysis by grouping factors in Analysis->Descriptive Statistics
  * Rework help start page to serve as a dashboard for common tasks, replacing the old startup dialog
- Bug fixes
  * Fixed: Disabling a element in plugins would not make the sub-elements non-required
  * Fixed some problems with cancelling running commands
  * Fixed: Package installation as root would fail to find kdesu/kdesudo on recent systems
  * Fixed: R help pages would refuse to open in new tab
  * Fixed: Windows: Issues with some shiny apps due to a too small stack size
  * Fixed: Installation from dialog would fail for R packages requiring the rkward package
  * Fix quirks around "Save as" for rkward output documents
* Tue Apr 19 2022 Wolfgang Bauer <wbauer@tmo.at>
- Update to upstream release 0.7.3
- New features and improvements
  * Add option to show standardized coefficients for linear regression
  * Add setting to allow hiding R Console scrollbar minimap
  * "Spontaneous" output, such as from running examples in the enhanced help system in R 4.2.0, is shown in the R Console
  * Support for switching color schemes, including basic support for dark mode
  * Space-saving placement of main window status bar, and display more tips in it
  * Implement R 4.2 graphics functions: stroked and filled paths, groups, luminance masks
  * Implement R 4.1 graphics functions: gradients, patterns, clip paths, masks
  * Add icons to settings dialog for quick visual orientation
  * Merge ktexteditor (script) settings into the main settings dialog
  * Internal: Code cleanup around settings, and in many other places
  * On exit, ask for saving all unsaved modified files at once
  * Output file handling has been reworked, entirely
  * rkwardtests library gains helper functions for checking for expected errors
  * Internal: Allow R-level calls to support both subcommands, and a return value at the same time
  * Hide or remove several purely internal functions (most can still be accessed from the rkward namespace as rkward:::xyz())
  * Use top alignment button to close (warning) messages in preview windows/areas
  * (Try to) automatically create custom R library locations, if they do not exist
  * kate plugin related actions are now active whenever a script window is active (not only the corresponding tool window)
- Bug fixes
  * Fixed: Possible backend hang when closing a data editor before it was done fetching its data
  * Fixed: Crash when installing packages from within check installation dialog
  * Fixed: Spurious string I18N_ARGUMENT_MISMATCH in several plugins
  * Fixed: Accordeon control (used in "Recode categorical data") never expanded
  * Fix compilation with the upcoming R 4.2.0
  * Fix crash in dev.capture()
  * Fix plot window not showing when created attached
  * Fixed: Initial graphics window size would be (mostly) ignored
  * Fix some buglets around closing on-screen devices
  * Fixed: Cursor navigation in completion list
  * Fixed: Calling (rk.)select.list() without a title would fail
  * Workaround for invalid EDITOR variable set by Kate Terminal plugin (also fixed in recent kate)
  * Fixed: Crash when attempting to use new graphics features in R 4.1.0 (esp. plotting using ggplot2)
- Drop patch-fix-crash-ggplot2.diff, merged upstream
- Add Source URL
* Sun Mar 13 2022 Wolfgang Bauer <wbauer@tmo.at>
- Adjust filelist to a recent kf5-filesystem change in Factory to
  fix build
* Sun Jul  4 2021 Pierre Bonamy <flyos@mailoo.org>
- Patch (patch-fix-crash-ggplot2.diff) fixing a severe issue when
  using ggplot2, see https://bugs.kde.org/show_bug.cgi?id=438993
* Wed Oct 21 2020 Wolfgang Bauer <wbauer@tmo.at>
- upstream release 0.7.2
- New features and improvements
  * Script preview keeps vertical scroll position when updating
  * Add function rk.home() for retrieving application paths, similar to R.home()
  * Add menu option to switch application language
  * Remove direct dependency on libintl
  * Add "Check installation" wizard to test for several common basic installation issues all in one place
  * Add rkward internal package location to end of library search path, to make it accessible to help.search()
  * Add menu action to open any supported file type, directly
  * Support using QWebEngine instead of QtWebKit (still supported)
  * <text> elements in plugins may now also contain clickable links, including rkward://-scheme links
  * The new code hinting features from version 0.7.1 are now also available in the console
  * On unix-systems, RKWard can now be run without installation
  * Kate addons are now supported within RKWard. Intially, search-in-files, snippets, and projects are loaded by default
  * Python development scripts have been ported to python3
- Bug fixes
  * Fix some problems with plot preview in wizard-type plugins
  * Fix several small memory leaks
  * Clean some logged warnings and potential issues during R backend shutdown
  * Fixed: Avoid shortcut clash with kate part by removing conflicting (default) shortcuts, automatically
- Recommend kate-plugins that are usable in rkward now
- Build with QtWebEngine (instead of QtWebKit) on architectures
  and distributions where it is available (in a new enough version)
- Remove no longer available NO_R_XML cmake option
* Mon May 25 2020 Wolfgang Bauer <wbauer@tmo.at>
- upstream release 0.7.1b
  * Workaround to avoid bug in R 4.0.0 when using for loop on top
    level context (kde#421958)
  * Fixed: Hang when opening an empty workplace (kde#420888)
  * Fixed: Crash when mousing over code preview window with
    focus-follows-mouse enabled (kde#420588)
- Update URL
- Run spec-cleaner
* Fri Jan 24 2020 Wolfgang Bauer <wbauer@tmo.at>
- upstream release 0.7.1
- New features and improvements
  * Code hinting in script editor windows has been reworked, and now also completes argument names
  * Instead of installing rkward R packages at build time, install them at runtime, when needed
  * Add new commandline option "–r-executable=auto" for auto-detection of R installation
  * element in save file mode gains checkbox to control overwriting of existing files
  * Add command-line option –autoreuse to avoid shipping two separate .desktop files
  * <select> elements in plugin dialogs can be set to accept only a single selection
  * New R functions rk.capture.output() and and rk.end.capture.output()
  * Allow to reference current script file in plugins
  * Add various live-preview options for R scripts, including a preview of R markdown rendering
  * Make it possible to "link" to specific settings pages from the internal documentation
  * Slightly less confusing output in case a package is installed from require(), such as in many plugins
  * Remove a bit of unused empty space around the main area of plugin dialogs
  * Expand root level objects (esp. data.frames) by default in plugin object lists. Add button to toggle back to collapsed.
  * Allow Tab-key to advance to the next row of data in data editor
  * Do not attempt object name hinting behind empty quoted strings or spaces.
  * rk.show.question() gains a parameter to allow setting a default button other than "yes"
  * new function rk.askYesNo() combines the functionality of askYesNo() (R >= 3.5.0) with rk.show.question() and is the default option for askYesNo() calls
  * Compile in ui definitions, instead of providing them as separate files
  * Offer R_LIBS_USER, instead of ~/.rkward/library as standard library installation location
  * Support R version placeholder (%%v) in custom library locations.
  * File browser tool window follows changes in current working directory (while showing current working directory)
  * Show focus indication in highlighted item color (usually blue), instead of hardcoded red
- Bug fixes
  * Fixed: Underscore (_) was not accepted in names of newly created data.frames
  * Fixed: <browser> element could not be set to not required
  * Fixed: max.print option was not saved, correctly, when set from RKWard settings
  * Fixed: RKWard icon was missing for the "enhances RKWard" column in package installation dialog
  * Fixed a layout issue in plugins using <stretch>-elements that would sometimes also render top-left aligned UI-elements unusable.
  * Fix highlighting of "trailing" rows and columns in data editor
  * Fixed: Loading existing workspace from startup dialog failed silently.
  * Support handling of help:/ pages (e.g. RKWard plugins documentation) inside the RKWard help window, again.
  * Fix printing of strings with R 3.5.0 on Windows in the console
  * On Mac, do not attempt to start DBus, if it is already running
  * Fix most compiler warnings
  * File tool window gains button to switch to current working directory
  * Fix a crash when closing a plugin dialog with an active plot preview
  * Do not throw an error on objects that return non-numeric/non-scalar dim()
- Drop patches merged upstream:
  * Fix-compilation.patch
  * Another-missing-include-file.patch
  * Another-include-file-fix.patch
* Fri Nov  1 2019 Detlef Steuer <detlef.steuer@gmx.de>
- moved COPYING to %%license line
* Fri Aug 23 2019 wbauer@tmo.at
- Add upstream patches to fix build in Factory:
  * Fix-compilation.patch
  * Another-missing-include-file.patch
  * Another-include-file-fix.patch
* Tue Apr 17 2018 wbauer@tmo.at
- Disable installation of r.xml again, syntax-highlighting (and
  ktexteditor before it) already contains a newer version anyway
* Tue Apr 17 2018 wbauer@tmo.at
- upstream release 0.7.0b
  * First release of RKWard to be based on KF5 (version 5 of the
  KDE libraries)
- Most important changes:
- New features and improvements
  Implement "split view" feature, allowing to partion the main window, and to have several views of the same files / data side-by-side
  Double click on object in Workspace browser tries to open reference page, not object viewer, if the object is outside of .GlobalEnv
  Limit the number of debug log-files to keep (at most three, each, for frontend and backend)
  Remove Windows-only UI for setInternet2()-option (no longer available in R, with setInternet2(TRUE) the default since R 3.2.2)
  Remove startup wrapper script (moving the still-needed functionality into the main executable)
  Preview status messages can now be closed
  Show the message accompanying rk.show.files() or rk.edit.files() inside the main window, instead of a separate dialog
  File browser gains "Rename" context menu action
  File selection fields in plugin dialogs remember the last used directory (per session), and check for a valid selection
- Bug fixes
  Fix crash with R 3.5.x due to use to STRING_PTR
  Fixed: Creating trellis on-screen plots, while package lattice is not on the search path would produce errors in plot history mechanism
  Function argument hinting is less easily fooled by braces inside quotes
  Better handling of text drag-and-drop inside the R console window
  Fix NAs introduced by editing data containing characters that cannot be encoded in the system locale
  Fixed: Preview boxes followed by a <stretch/> element would not work under some circumstances
  Fixed: Setting an output CSS file via the GUI did not work
  Fixed: Bug report feature on Windows did nothing
  Avoid some potential encoding issues, that could cause graphical select.list to fail for certain strings, under some circumstances
- Fix versioned package dependency on R-base, it was spelt R-Base
  by mistake and therefore ineffective (boo#993268)
- Drop rkward-translations.tar.xz, the translations are included in
  the released tarball as usual
* Fri Dec  8 2017 wbauer@tmo.at
- Update to latest snapshot of the "frameworks" git branch (WIP
  port to Qt5/KF5), the KDE4 version cannot be built or installed
  anymore on Tumbleweed and Leap 15 as Qt4WebKit is to be dropped
- Add rkward-translations.tar.xz containing the latest translations
  from SVN
* Fri Aug 12 2016 astieger@suse.com
- rwkard needs the R-Base version it was compiled with - boo993268
* Wed Jun 29 2016 jengelh@inai.de
- Drop obsolete %%clean section
* Thu Jun  9 2016 wbauer@tmo.at
- Don't delete %%{_libdir}/R/library/R.css in the %%install section,
  it doesn't exist in the first place
* Wed Jun  8 2016 wbauer@tmo.at
- upstream release 0.6.5
- Most important changes:
- New features and improvements
  Add option to override CSS file used for the output window
  Added context menu option to search for information on current symbol online
  Provide better status feedback when searching / filtering among installable packages
  Add access to basic menu items for docked previews
  Move preview controls to the button-column of dialogs
  Add preview to Sort data-, Subset data, and Recode categorical data-plugins
  Add preview to Power Analysis plugin
  Add support for adding "htmlwidget"- and "gvis"-class objects to the output window via rk.print()
  Add plugins for importing Excel files (.xls and .xlsx, Perl- and Java-based)
  Add ability to extract <matrix> values row-wise in plugins
  Add convenience JS-function "makeOption()" for use in plugins
  Add previews for CSV, SPSS, and Stata import plugins
  Allow previews for data, (HTML) output, and custom types of previews
  Allow previews to be docked to the dialog window, and dock them, by default
  Implicitly save code preview visibility and size (instead of the former explicit settings)
  data.frame objects outside of globalenv() can be opened read-only in an editor window
  Show a warning screen when invoking plugins from the command line (or from clicking an rkward://-link in an external application)
  Use package type option "binary" from R 3.1.3 onwards, for automatic selection of the appropriate binary package
- Fixes
  When manually adding pluginmaps, load these after, not before other pluginmaps, by default
  Fixed: Wizard plugins would be too small, initially
  Fixed: Help Search was not longer working correctly with R 3.2.x
  Fix compilation with R 3.3.x
  Fixed: Numerical (display) precision setting was not honored in data editor
  Fix several window activation quirks in "Focus follows mouse" mode
  File selectors in "Import XYZ" plugins now filter for standard file extensions, by default
- upstream release 0.6.4
- Most important changes:
- New features and improvements
  Plugins check for correct object type, in more places, but allow to proceed with questionable object selections
  Switch to bugs.kde.org as primary issue tracker
  Workspace browser gains functionality to search / filter objects by name, making it easy to find objects, quickly
  Separate globalenv() and other environments in the search path more clearly in workspace browser
  Complete rework of <optionset> UI for better usability
  Some usability refinements to "Import CSV" plugin
  Disabled the "Import Data"-dialog, as it was considered too confusing. The individual importers are still available from the menu, separately.
  For multi-item varslots and valueslots, use separate buttons for adding / removing items
  Don't show (useless) index number in mutli-value varslots and valueslots
  Make the option to disable / enable editing more visible (in the data editor's toolbar)
  Add context menu to HTML viewer window, including the ability to open links in a new window
  Remove dependency on KHTMLPart
- Fixes
  Fixed: Plugin variable slots taking more than one object would not be highlighted in red while invalid
  Fixed: RKWard package repository would be listed twice on fresh installations
  Fix some minor toolbar glitches
  Try harder to honor system locale settings
  Remove obsolete "Export tabular data" plugin (superceded by "Export Table / CSV")
  Do not invoke symbol name completion while in the middle (not end) of a word
- Use the NO_R_XML cmake option instead of manually deleting the R
  syntax highlighting file (which is also included in libktexteditor)
* Fri Mar 13 2015 detlef.steuer@gmx.de
- upstream release 0.6.3
- Most important changes:
- New features and improvements
  New element <i18n> for use in plugins' logic section: Provides a translatable string property
  New element <label> for use in plugin help pages: Copies the label-attribute of the given element into the text
  New string property modifier "quoted" to make it easier to quote dynamic strings inside plugins
  Reworked distribution calculator plugins
  Added power analysis plugin (already existed as separate plugin)
  Assume plugin .js files to be in utf-8 encoding; this allows using non-ascii characters in the generated code
  <matrix> element gains options min_rows and min_columns, and the details of fixed_width="true" have been improved
  Add R function rk.set.plugin.status() to allow further customization of loaded plugins (hiding of individual menu entries)
  Pluginmap-management was reworked, partially, and moved to Settings->Manage R packages and plugins
  Provide more detailed information on loaded plugins in rk.list.plugins()
  Allow to override plugins from a different pluginmap (the plugin with the highest specified version is used)
  When the RKWard installation has moved on disk, try to adjust stored .pluginmaps paths, accordingly
  Allow opening RKWard's plugin files (with correct highlighting), and other text files
  More robust control over placement of plugins within a menu
  Restructure layout of CSV-import dialog
  Allow to open (any number of) R script files and rkward://-urls from the command line
  Add command line option --reuse for reusing an existing instance of RKWard
  Be slightly(!) smarter about when (not) to ask for saving workspace on workspace load (e.g. not directly after workspace has been saved)
  Change default in Workspace browser to showing only .GlobalEnv, initially
  Support automatically generating a printable header parameter from most plugin elements
  New Object based convience method for printing headers from plugins
  Implement polyPath()-drawing in RK() device
  Pre-compile the common js code included in every plugin (only when compiled with Qt >= 4.7)
  Improve crash recovery dialog to not prompt again for the same files
  Plugins and in-application help pages can now be fully translated
- Fixes
  Fixed: Hang when trying to select existing directories in file selectors on Windows
  Fixed: <valueslot>s were quirky with respect to showing as invalid
  Fix a hang-on-exit issue
  Fixed: Error when using fix() or trace(...edit=TRUE) with default settings on some systems
  Fixed: Freezes when using RKWard-functionality (such as the RK()-device) from tcl/tk (e.g. Rcmdr)
  Fix several issues of excessive printing of digits in plugins' output
  Fixed potential crash while the "RKWard Debug Messages" window is visible
  Fixed display of file paths containing non-ascii characters in the title bar and startup dialog
  Fixed some erroneous plugin debug messages
* Tue Nov 11 2014 detlef.steuer@gmx.de
- upstream release 0.6.2
- Most important changes:
- In data editor, indicate NAs, explicitly
- Import Stata plugin gains option to convert character encoding.
- New embeddable (minimal) plugin "multi_input" to combine different input elements
- Fixed: Problems starting from paths with spaces in the file name on Windows
- Added command line option --r-executable for switching between several installations of R
- Use a binary wrapper, instead of wrapper shell script for startup on all platforms
- Linear regression plugin gains option to save predicted values
- Fixed some compilation problems
- Add basic support to export plots using tikzDevice
- Fixed: cbind-value of <matrix> element was missing commas
- Fixed: Give a label to an unlabelled toolbar
- Fixed: Adjust to (re-?)named parameters for options("pager")
- Allow plugin UI script code to query R for information
- Fixed: potential crash when a previously installed pluginmap is not longer readable
- Allow to connect <varslot>/<valueslot> source to any property, not just <varselectors>
- New plugin elements <valueselector> and <select>
- New plugin element <valueslot> for selecting arbitrary string values (otherwise almost identical to <varslot>)
- <varslots> can be set to accept the same object several times. Used in scatterplot plugin.
- New R function rk.embed.device() for manually embedding graphics devices in RKWard
- Fixed: R backend would exit immediately, without meaningful error message, if there is an error in .Rprofile (or Rprofile.site)
- Fixed: Installing suggested packages from the package installation dialog was broken
- Fixed: Selecting a mirror via the "R packages" settings page would not work when prompted for package installation form the backend
- Remove support for compiling RKWard in a single process (threaded) variant. This was not used / tested since RKWard 0.5.5
- Shortcuts for the "Run ..." actions have been changed for better cross-platform compatibility
- The script editor's "Run line" and "Run selection" actions have been merged
- Add UI for configuring default graphics device, and embedding of standard graphics devices.
- New RKWard native on-screen device (RK()). This is the default on-screen device in RKWard, now.
- New R function rk.without.plot.history() for turning off plot history, temporarily
- Add command line option --backend-debugger
* Mon Apr  8 2013 detlef.steuer@gmx.de
- Update to R-3.0.0. Note: it works with R-3.0.0 only if compiled against.
  If compiled against an older version, i.e. against 2.15.2 as in 12.3 it
  won't work with a newer version and must be recompiled.
- Update notes from upstream:
--- Version 0.6.1 - Apr-02-2013
- Add option to force-close a graphics window
- Add plugin for subsetting data.frames by rows or columns
- On the Windows platform, add an new (experimental) binary startup wrapper (rkward.exe)
- Revert to building R packages form source on Mac OS X by default (controllable via compile-time option)
- Fixed: lattice plots would not be added to the plot history, correctly, for some versions of lattice
- Fix crash when trying to print, and neither okular, nor kpdf are available
- Added support for loaded namespaces that are not attached to a loaded package
- Pluginmaps can specify their "priority". Pluginmaps with low priority will not be added automatically, when found.
- Pluginmaps can <require> other pluginmaps based on their id (for cross-package inclusion)
- Added new element <dependency_check> for dynamic version checks within a plugin (R and RKWard versions, only, so far)
- Add guard against accidental usage of the standard distributed pluginmaps in a later version of RKWard (installed in parallel)
- Easier (de-)activation of RKWard plugin maps using checkboxes (Settings->Configure RKWard->Plugins)
- Broken or quirky .pluginmap files are reported to the user, completely broken maps are disabled, automatically
- Implement basic dependency handling for plugins / pluginmaps
- Added support for the upcoming R 3.0.0                        TODO: Check for any more regressions, before release
- Added <switch> logic element to switch between several target properties (or fixed values) based on the value of a condition property
- Sort plugin gains option to sort data.frames by more than one column at a time, and options for type conversion
- Add in-application debug message viewer (targetted at (plugin) developers)
- Add setting to customize initial working directory
- Windows only: Add UI-checkbox for R's "internet2"-option
- New functions getString(), getList() and getBoolean() for fetching data in plugin scripts
- Boolean properties now return a numeric, not labelled representation of their value, by default. <checkbox>es should be unaffected.   TODO: when announcing release, link to explanation mail.
- Added <optionset> GUI element for entering a set of options for an arbitrary number of items
- Reduce CPU usage of pluings while idle
- Fix conversion from Numeric to Factor in the data editor
- In the data.frame editor, columns containing invalid values are now highlighted in red
- Fixed: If none of the previous plugin maps could be found on startup, re-add the default
- Added <matrix> GUI element for entering matrix or vector data in plugins
- Improve key handling while editing factor levels in a data.frame
- Added utiltity function rk.flush.output()
- RKWard is now categorized as Science/Math/Numerical Analysis in its .desktop file
- Fixed: Yet another fix for hard-to-read function argument hints
- Fixed: Device history was not working with more recent versions of ggplot2
- Fixed: Option to include suggested packages in install was mis-labelled "install dependencies"
- rk.set.output.html.file() gains argument to allow addition of custom content to the html header
* Fri Nov  2 2012 detlef.steuer@gmx.de
- aj asked for details why a user should update.
- Note: I'm only the packager, not even using this software
- myself. But if you ask: here is upstream's list of improvements:
  New features and improvements
    Preview device windows will display some status information (most importantly, warnings or errors)
    Most plot plugins gain options to control margins and tick label orientation
    Added option for installing packages from source (implicitly enabled on Unixoid platforms)
    Omit comments on missing function calls in dialog code windows (e.g., if prepare() is unused, there's no "## Prepare" in the output either)
    Output markup is now more XHTML compliant and easier to parse
    Also save cursor position, folding, etc. for scripts. Note: Implementation details may be subject to change.
    New function rk.list.labels() to retrieve column labels in a data.frame
    rk.get.label() will now return an empty string ("") instead of NULL, in case no label is assigned
    Do not offer to restore individual removed columns of a data.frame opened for editing
    combined all Wilcoxon/Mann-Whitney-tests in one plugin (from previously two separate plugins)
    Added polyserial/polychoric correlations to correlation matrix plugin
    Added more compression options to the "Save objects as R code" plugin
    Added MacPorts support, see README.MacPorts and bundle build script in the macports folder
    Added dynamically generated table-of-contents menu to output document
    Allow some markup inside <text> elements in plugins, and auto-add breaks only for duplicate newlines.
    Reorganized t-test plugin, and add support for single sample t-tests
    Box plot plugin gains more options for adding means
    Improve keypress handling issues in the R Console, when the cursor or a selection is outside the editable range
    Only install translations which are at least 80%% complete (not counting strings in plugins, which are not yet translatable)
    When asking for workspace file to open, use appropriate file filter
    When configured to ask for workspace to open on startup, don't prompt to save, first
    Simplified the "Sort Data" plugin, and added a help page
    Added GUI support for inspecting the call stack during debugging
    The backend executable is no longer linked against KDE libraries
    Objects, which are not acceptable in a varslot, will still be shown, there, with a warning
    Bugfixes
    Fixed: Entering "0" as propabilities (quantiles) vector in distribution plugins would cause error message
    Fixed: Wrong handling of carriage returns ('\r') in the console window
    Fixed: Spinboxes had wrong initial values
    Fixed: Changed configuration settings would not be saved for script editor
    Fixed: One character missing in R commands on lines longer than 4096 characters
    Fixed: "Next"-button in wizards would remain enabled while settings are missing on a page
    Fixed: Dynamic pages in a wizard would cause a layout bug on the first page
    Fixed: Plot history and graphical menus broken in some cases with R 2.15.0
    Fixed: If the rkward package was loaded in a plain R session, q() and quit() still work
    Fixed: Would not show output of system() commands to stderr on the console (on Unix-like systems)
    Fixed: Function argument hints for the second half of the parameter list would not be quoted, correctly
    Fixed: Failure to open workspaces with non-latin1 filenames from the command line
    Fixed: Saving / restoring workplace layout would fail when saving to directories with unusual characters
    Fixed: potential crash when clicking "Select all updates" in the package installation dialog
    Fixed: potential crash in object name completion under certain conditions
    Fixed: On Windows, detached windows would sometimes be positioned with the menubar outside the upper screen edge
* Wed Oct 31 2012 detlef.steuer@gmx.de
- upstream release 0.6.0
- from a packager view nothing changed besides version number
- details:
- http://sourceforge.net/apps/mediawiki/rkward/index.php?title=News#RKWard_0.6.0_is_available_-_also_on_the_Mac
* Thu Jan 12 2012 detlef.steuer@gmx.de
- directory ownership for rkwardplugins added
* Mon Dec 12 2011 detlef.steuer@gmx.de
- Update to upstream version 0.5.7
- Support for R-2.14.0
- Improvements for add-on handling
- many bug fixes
* Mon Aug 29 2011 detlef.steuer@gmx.de
- Fixed another directory ownership, now builds fine
* Sat Aug 27 2011 aj@suse.de
- Fix spec list by owning a directory.
* Thu Jun 30 2011 detlef.steuer@gmx.de
- Update for upstream new version 0.5.6
  Submitrequest into Factory
* Mon May  9 2011 detlef.steuer@gmx.de
- First submitrequest of rkward into Factory
  rkward  is a kde4 frontend for the statistical software R, which is part of
  11.4 and Factory.
